@@ -184,7 +184,9 @@ class PDFQuery(object):
             # pdfminer >= 20131022
             doc = QPDFDocument(parser)
             parser.set_document(doc)
-        doc.initialize()
+        if hasattr(doc, 'initialize'):
+            # as of pdfminer==20140328, "PDFDocument.initialize() method is removed and no longer needed."
+            doc.initialize()
         self.doc = doc
         self.parser = parser
         self.tree = None
